@@ -21,19 +21,35 @@ from pyvisa.errors import (Error, VisaIOError, VisaIOWarning, VisaTypeError,
 # This is needed to registry all resources.
 from pyvisa.resources import Resource
 
-if __name__ == '__main__':
+def visa_main(command=None):
     import argparse
     parser = argparse.ArgumentParser(description='PyVISA command-line utilities')
-    subparsers = parser.add_subparsers(title='command', dest='command')
 
-    info_parser = subparsers.add_parser('info', help='print information to diagnose PyVISA')
+    parser.add_argument('--backend', '-b', dest='backend', action='store', default=None,
+                        help='backend to be used (default: ni)')
 
-    console_parser = subparsers.add_parser('shell', help='start the PyVISA console')
+    if not command:
+        subparsers = parser.add_subparsers(title='command', dest='command')
+
+        info_parser = subparsers.add_parser('info', help='print information to diagnose PyVISA')
+
+        console_parser = subparsers.add_parser('shell', help='start the PyVISA console')
 
     args = parser.parse_args()
+    if command:
+        args.command = command
     if args.command == 'info':
         from pyvisa import util
         util.get_debug_info()
     elif args.command == 'shell':
         from pyvisa import shell
-        shell.main()
+        shell.main('@' + args.backend if args.backend else '')
+
+def visa_shell():
+    visa_main('shell')
+
+def visa_info():
+    visa_main('info')
+
+if __name__ == '__main__':
+    visa_main()
